@@ -51,7 +51,7 @@ class about : public QDialog, private Ui::AboutDlg{
       // Set icons
       logo->setPixmap(QPixmap(QString::fromUtf8(":/Icons/skin/qbittorrent22.png")));
       //Title
-      lb_name->setText(QString::fromUtf8("<b><h1>")+tr("qBittorrent")+QString::fromUtf8(" "VERSION"</h1></b>"));
+      lb_name->setText(QString::fromUtf8("<b><h1>qBittorrent")+QString::fromUtf8(" "VERSION"</h1></b>"));
       // Thanks
       QString thanks_txt;
       thanks_txt += QString::fromUtf8("<p>I would first like to thank sourceforge.net for hosting qBittorrent project and for their support.</p>");
@@ -93,7 +93,7 @@ class about : public QDialog, private Ui::AboutDlg{
           <li><u>Russian:</u> Nick Khazov (m2k3d0n@users.sourceforge.net) and Alexey Morsov (samurai@ricom.ru)</li>\
           <li><u>Serbian:</u> Anaximandar Milet (anaximandar@operamail.com)</li>\
           <li><u>Slovak:</u>  helix84</li>\
-          <li><u>Spanish:</u> Francisco Luque Contreras (frannoe@ya.com)</li>\
+          <li><u>Spanish:</u> Alfredo Monclús (alfrix), Francisco Luque Contreras (frannoe@ya.com)</li>\
           <li><u>Swedish:</u> Daniel Nylander (po@danielnylander.se)</li>\
           <li><u>Turkish:</u> Hasan YILMAZ (iletisim@hedefturkce.com) and Erdem Bingöl (erdem84@gmail.com)</li>\
           <li><u>Ukrainian:</u> Oleh Prypin (blaxpirit@gmail.com)</li></ul>");
