@@ -85,6 +85,10 @@ void RSSImp::displayRSSListMenu(const QPoint& pos) {
         }
       }
     }
+    else {
+      myRSSListMenu.addAction(actionDelete);
+      myRSSListMenu.addSeparator();
+    }
     myRSSListMenu.addAction(actionNew_subscription);
     if (m_feedList->isFeed(selectedItems.first())) {
       myRSSListMenu.addSeparator();
@@ -167,12 +171,6 @@ void RSSImp::askNewFolder() {
   }
 }
 
-void RSSImp::displayOverwriteError(const QString &filename) {
-  QMessageBox::warning(this, tr("Overwrite attempt"),
-                       tr("You cannot overwrite %1 item.", "You cannot overwrite myFolder item.").arg(filename),
-                       QMessageBox::Ok);
-}
-
 // add a stream by a button
 void RSSImp::on_newFeedButton_clicked() {
   // Determine parent folder for new feed
@@ -206,7 +204,7 @@ void RSSImp::on_newFeedButton_clicked() {
     newUrl = newUrl.trimmed();
     if (!newUrl.isEmpty()) {
       if (m_feedList->hasFeed(newUrl)) {
-        QMessageBox::warning(this, tr("qBittorrent"),
+    QMessageBox::warning(this, "qBittorrent",
                              tr("This rss feed is already in the list."),
                              QMessageBox::Ok);
         return;
@@ -668,7 +666,6 @@ RSSImp::RSSImp(QWidget *parent) : QWidget(parent), m_rssManager(new RssManager)
 
   connect(m_feedList, SIGNAL(currentItemChanged(QTreeWidgetItem*,QTreeWidgetItem*)), this, SLOT(refreshArticleList(QTreeWidgetItem*)));
   connect(m_feedList, SIGNAL(foldersAltered(QList<QTreeWidgetItem*>)), this, SLOT(updateItemsInfos(QList<QTreeWidgetItem*>)));
-  connect(m_feedList, SIGNAL(overwriteAttempt(QString)), this, SLOT(displayOverwriteError(QString)));
 
   connect(listArticles, SIGNAL(itemSelectionChanged()), this, SLOT(refreshTextBrowser()));
   connect(listArticles, SIGNAL(itemDoubleClicked(QListWidgetItem *)), this, SLOT(downloadTorrent()));
