@@ -67,6 +67,7 @@ using namespace libtorrent;
 TransferListWidget::TransferListWidget(QWidget *parent, MainWindow *main_window, QBtSession *_BTSession):
   QTreeView(parent), BTSession(_BTSession), main_window(main_window) {
 
+  setUniformRowHeights(true);
   // Load settings
   bool column_loaded = loadSettings();
 
@@ -90,7 +91,7 @@ TransferListWidget::TransferListWidget(QWidget *parent, MainWindow *main_window,
   statusFilterModel->setFilterKeyColumn(TorrentModelItem::TR_STATUS);
   statusFilterModel->setFilterRole(Qt::DisplayRole);
 
-  nameFilterModel = new QSortFilterProxyModel();
+  nameFilterModel = new TransferListSortModel();
   nameFilterModel->setDynamicSortFilter(true);
   nameFilterModel->setSourceModel(statusFilterModel);
   nameFilterModel->setFilterKeyColumn(TorrentModelItem::TR_NAME);
@@ -131,6 +132,8 @@ TransferListWidget::TransferListWidget(QWidget *parent, MainWindow *main_window,
   connect(this, SIGNAL(customContextMenuRequested(const QPoint&)), this, SLOT(displayListMenu(const QPoint&)));
   header()->setContextMenuPolicy(Qt::CustomContextMenu);
   connect(header(), SIGNAL(customContextMenuRequested(const QPoint&)), this, SLOT(displayDLHoSMenu(const QPoint&)));
+
+  editHotkey = new QShortcut(QKeySequence("F2"), this, SLOT(renameSelectedTorrent()), 0, Qt::WidgetShortcut);
 }
 
 TransferListWidget::~TransferListWidget() {
@@ -143,6 +146,7 @@ TransferListWidget::~TransferListWidget() {
   delete nameFilterModel;
   delete listModel;
   delete listDelegate;
+  delete editHotkey;
   qDebug() << Q_FUNC_INFO << "EXIT";
 }
 
@@ -605,15 +609,17 @@ void TransferListWidget::renameSelectedTorrent() {
   const QModelIndexList selectedIndexes = selectionModel()->selectedRows();
   if (selectedIndexes.size() != 1) return;
   if (!selectedIndexes.first().isValid()) return;
-  const QString hash = getHashFromRow(mapToSource(selectedIndexes.first()).row());
+  QModelIndex mi = mapToSource(selectedIndexes.first());
+  const QString hash = getHashFromRow(mi.row());
   const QTorrentHandle h = BTSession->getTorrentHandle(hash);
   if (!h.is_valid()) return;
   // Ask for a new Name
   bool ok;
-  const QString name = QInputDialog::getText(this, tr("Rename"), tr("New name:"), QLineEdit::Normal, h.name(), &ok);
+  QString name = QInputDialog::getText(this, tr("Rename"), tr("New name:"), QLineEdit::Normal, h.name(), &ok);
   if (ok && !name.isEmpty()) {
+    name.replace(QRegExp("\r?\n|\r"), " ");
     // Rename the torrent
-    nameFilterModel->setData(selectedIndexes.first(), name, Qt::DisplayRole);
+    listModel->setData(mi, name, Qt::DisplayRole);
   }
 }
 
